/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 1002 $
 * $Date: 2020-04-10 23:31:24 +0200 (Fri, 10 Apr 2020) $
 */
package at.lcm.bu21.general.dtypes.editor;

import java.util.Vector;

import javax.swing.JComboBox;

import at.lcm.bu21.general.dtypes.TBoolean;
import at.lcm.bu21.general.dtypes.TData;
import at.lcm.bu21.general.dtypes.TNumeric;
import at.lcm.bu21.general.dtypes.TPeriodic;
import at.lcm.bu21.general.dtypes.TString;

/**
 * @author Christoph Halbmayr
 */
class TableModelChangePanel extends TableModelListPanel {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/**
	 * Creats an empty Object
	 */
	public TableModelChangePanel() {
		super();

	}

	/**
	 * adds a TData to the Model
	 * 
	 * @param selection
	 *            TData
	 */
	public void addTData(final TData selection) {

		final Vector<String> titles = new Vector<String>();
		Vector<String> row = new Vector<String>();

		if (selection.getClass().getName().equals("at.lcm.bu21.general.dtypes.TString")) {

			final TString ts = (TString) selection;

			titles.add("TString ");

			this.setColumnIdentifiers(titles);

			row.add(ts.getString() + " ");
			this.addRow(row);

		}

		if (selection.getClass().getName().equals("at.lcm.bu21.general.dtypes.TBoolean")) {

			final String[] b = new String[2];
			b[0] = "true";
			b[1] = "false";

			final JComboBox cb = new JComboBox(b);
			cb.setEditable(false);

			final TBoolean tb = (TBoolean) selection;

			titles.add("TBoolean ");

			this.setColumnIdentifiers(titles);
			if (tb.getBoolean() == true) {
				cb.setSelectedIndex(0);
			} else {
				cb.setSelectedIndex(1);
			}

			row.add("" + tb.getBoolean());
			this.addRow(row);

		}

		if (selection.getClass().getName().equals("at.lcm.bu21.general.dtypes.TNumeric")) {

			final TNumeric tb = (TNumeric) selection;

			final int rowSize = tb.size()[0];
			final int colSize = tb.size()[1];

			final String[] titel = new String[colSize];

			for (int i = 0; i < colSize; i++) {
				titel[i] = "" + i;
			}

			final String[][] data = new String[rowSize][colSize];

			for (int x = 0; x < rowSize; x++) {
				for (int y = 0; y < colSize; y++) {
					data[x][y] = tb.getStringVal(x, y);
				}
			}

			this.setDataVector(data, titel);

		}

		if (selection.getClass().getName().equals("at.lcm.bu21.general.dtypes.TPeriodic")) {

			final TPeriodic tp = (TPeriodic) selection;

			titles.add("Order:  ");
			titles.add("A:  ");
			titles.add("B:  ");
			titles.add("magnitude: ");
			titles.add("phase: [DEG.]");

			this.setColumnIdentifiers(titles);
			for (final int i : tp.usedOrders()) {

				row = new Vector<String>();
				row.add("" + i);

				row.add(" " + tp.getCoeffA(i));

				row.add(" " + tp.getCoeffB(i));

				row.add(" " + tp.magnitude(i));

				double phase = tp.phase(i);

				phase *= 180 / Math.PI;

				row.add(" " + phase);

				this.addRow(row);

			}

		}

	}

	@Override
	public boolean isCellEditable(final int row, final int column) {
		return true;
	}
}
