/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 1002 $
 * $Date: 2020-04-10 23:31:24 +0200 (Fri, 10 Apr 2020) $
 */
package at.lcm.bu21.general.dtypes.editor2;

import java.awt.BorderLayout;

import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.ScrollPaneConstants;
import javax.swing.table.JTableHeader;

import at.lcm.bu21.general.dtypes.editor2.TDataModel.TBooleanModel;

/**
 * This panel allows to analyze and manipulate TBooleans. It based on
 * TBooleanModel and TBooleanTableModel for JTables.
 * 
 * @author Johannes Kaisinger
 */
public class TBooleanPanel extends JPanel {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/**
	 * Local reference of the tBooleanModel. It allows to manipulate the
	 * TBoolean.
	 */
	private TBooleanModel tBooleanModel;

	/** Contains a table model for the JTable. */
	private TBooleanTableModel tableModelTBoolean;

	/** Editor as table. */
	private JTable table;

	/**
	 * Creates an object
	 * 
	 * @param tBooleanModel
	 *            The TBooleanModel on which the panel based.
	 */
	public TBooleanPanel(TBooleanModel tBooleanModel) {

		this.tBooleanModel = tBooleanModel;

		this.tableModelTBoolean = new TBooleanTableModel(this.tBooleanModel);
		this.table = new JTable(this.tableModelTBoolean);
		this.table.setAutoResizeMode(JTable.AUTO_RESIZE_OFF);

		JTableHeader tableHeader = this.table.getTableHeader();
		tableHeader.setReorderingAllowed(false);

		JScrollPane scroll = new JScrollPane(this.table);

		RowHeaderTable rowHeaderTable = new RowHeaderTable(this.table);
		scroll.setRowHeaderView(rowHeaderTable);
		scroll.setCorner(ScrollPaneConstants.UPPER_LEFT_CORNER, rowHeaderTable.getTableHeader());

		this.setLayout(new BorderLayout());
		this.add(scroll, BorderLayout.CENTER);
		this.setVisible(true);
	}
}
