/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 997 $
 * $Date: 2020-03-19 13:49:34 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.general.dtypes.xsd;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;

import javax.xml.XMLConstants;
import javax.xml.transform.stream.StreamSource;
import javax.xml.validation.SchemaFactory;
import javax.xml.validation.Validator;

import org.xml.sax.SAXException;

/**
 * Validate data file
 * 
 * @author Werner Koppelsttter
 */
public class XMLDataValidator {

	/**
	 * Validate xml-data-file
	 * 
	 * @param file
	 *            Xml-file
	 * @param schema
	 *            Name of Schema
	 * @throws FileNotFoundException
	 *             File not found
	 * @throws SAXException
	 *             SAX exception
	 * @throws IOException
	 *             File exception
	 */
	public void validate(File file, String schema) throws FileNotFoundException, SAXException, IOException {
		this.validate(new FileInputStream(file), schema);
	}

	/**
	 * Validate xml-data-file
	 * 
	 * @param is
	 *            Inputstream of xml-data-file
	 * @param schema
	 *            Name of Schema
	 * @throws SAXException
	 *             SAX exception
	 * @throws IOException
	 *             File exception
	 */
	public void validate(InputStream is, String schema) throws SAXException, IOException {

		SchemaFactory schemaFactory;
		Validator vali;

		schemaFactory = SchemaFactory.newInstance(XMLConstants.W3C_XML_SCHEMA_NS_URI);
		vali = schemaFactory.newSchema(XMLDataValidator.class.getResource(schema)).newValidator();
		vali.validate(new StreamSource(is));
	}
}
