/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 997 $
 * $Date: 2020-03-19 13:49:34 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.general.math.autodiff.wrapper;

import org.apache.commons.math3.analysis.DifferentiableMultivariateFunction;
import org.apache.commons.math3.analysis.MultivariateFunction;
import org.apache.commons.math3.analysis.MultivariateVectorFunction;
import org.apache.commons.math3.exception.DimensionMismatchException;
import org.apache.commons.math3.exception.MathIllegalArgumentException;

import at.lcm.bu21.general.math.autodiff.Func;
import at.lcm.bu21.general.math.autodiff.Variable;

/**
 * @author gweidenholzer
 * 
 */
public class DMFWrapper2 implements DifferentiableMultivariateFunction {

	private Variable[] vars;
	private Func f;

	/**
	 * @param func
	 * @param vars
	 */
	public DMFWrapper2(Func func, Variable... vars) {
		this.f = func;
		this.vars = vars;
	}

	@Override
	public double value(double[] arg0) throws DimensionMismatchException, MathIllegalArgumentException {

		double val = Double.NaN;

		for (int k = 0; k < this.vars.length; k++) {
			this.vars[k].setVal(arg0[k]);
		}

		try {
			val = this.f.value();
		} catch (Exception e) {
			e.printStackTrace();
		}

		return val;
	}

	@Override
	public MultivariateVectorFunction gradient() {

		/**
		 * Gradient class
		 * 
		 * @author gweidenholzer
		 * 
		 */
		class Grad implements MultivariateVectorFunction {

			/** */
			DMFWrapper2 dmf;

			public Grad(DMFWrapper2 differentiableMultivariateFunction2) {
				this.dmf = differentiableMultivariateFunction2;
			}

			@Override
			public double[] value(double[] x) throws IllegalArgumentException {

				double[] grad = new double[DMFWrapper2.this.vars.length];
				for (int k = 0; k < DMFWrapper2.this.vars.length; k++) {
					grad[k] = this.dmf.partialDerivative(k).value(x);
				}

				return grad;
			}

		}

		return new Grad(this);

	}

	@Override
	public MultivariateFunction partialDerivative(int vIdx) {

		MultivariateFunction deriv = null;

		try {
			deriv = new DMFWrapper2(this.f.derivative(this.vars[vIdx]), this.vars);
		} catch (Exception e) {
		}

		return deriv;
	}

}
