/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9715 $
 * $Date: 2020-03-19 10:01:15 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.symspace.center.views.tree;

import java.awt.Color;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.Rectangle;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import javax.swing.BorderFactory;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JTable;
import javax.swing.table.JTableHeader;
import javax.swing.table.TableColumn;
import javax.swing.table.TableColumnModel;

import at.lcm.symspace.center.icons.tree.IconTreeTableView;
import at.lcm.symspace.center.views.indices.IndexViewDialog;

/**
 * 
 * @author Markus Priglinger
 * @author Werner Koppelsttter
 */
public class ProTreeTableHeaderSelectedIdxRenderer
		extends ProTreeTableAbstractHeaderRenderer {

	private static final long serialVersionUID = 19700717201305291L;
	protected JTableHeader _header = null;
	protected JLabel _label = null;
	JButton _button = null;
	protected int _column;
	protected boolean _mousePressed = false;
	protected int _selectedIndex = 0;

	private ProTreeTable _table = null;

	public ProTreeTableHeaderSelectedIdxRenderer(ProTreeTable table) {

		this._table = table;
		this.createComponent();
	}

	private void createComponent() {

		GridBagLayout gbl_panel = new GridBagLayout();
		gbl_panel.columnWidths = new int[] { 0, 0, 0 };
		gbl_panel.rowHeights = new int[] { 0, 0 };
		gbl_panel.columnWeights = new double[] { 0.0, 0.0, Double.MIN_VALUE };
		gbl_panel.rowWeights = new double[] { 0.0, Double.MIN_VALUE };
		this.setLayout(gbl_panel);
		this.setBorder(BorderFactory.createLineBorder(Color.RED));

		GridBagConstraints gbc_lblNewLabel = new GridBagConstraints();
		gbc_lblNewLabel.insets = new Insets(0, 11, 0, 5);
		gbc_lblNewLabel.gridx = 1;
		gbc_lblNewLabel.gridy = 0;

		this._label = new JLabel(" selected index: 0");
		this.setSelectedIndex(this._selectedIndex);
		this.add(this._label, gbc_lblNewLabel);

		GridBagConstraints gbc_btnNewButton = new GridBagConstraints();
		gbc_btnNewButton.insets = new Insets(0, 5, 0, 5);
		gbc_btnNewButton.gridx = 0;
		gbc_btnNewButton.gridy = 0;

		this._button = new JButton();
		this._button.setIcon(new ImageIcon(IconTreeTableView.ADD_IDX_VIEW));
		this._button.setToolTipText(
				"adds a new column in the table to view another index");
		this._button.setPreferredSize(new Dimension(16, 16));
		this.add(this._button, gbc_btnNewButton);

		this._table.getTableHeader().addMouseListener(new MouseAdapter() {
			@Override
			public void mousePressed(MouseEvent evt) {
				int dWidth = 0;
				if (ProTreeTableHeaderSelectedIdxRenderer.this._header == null) {
					ProTreeTableHeaderSelectedIdxRenderer.this._header = ProTreeTableHeaderSelectedIdxRenderer.this._table
							.getTableHeader();
				}

				JTable tableView = ProTreeTableHeaderSelectedIdxRenderer.this._header
						.getTable();
				TableColumnModel columnModel = tableView.getColumnModel();
				int viewColumn = columnModel.getColumnIndexAtX(evt.getX());
				int column = tableView.convertColumnIndexToModel(viewColumn);

				for (int i = 0; i < viewColumn; i++) {
					TableColumn tc = columnModel.getColumn(i);
					dWidth += tc.getWidth();
				}

				Rectangle columnAlignedBox = ProTreeTableHeaderSelectedIdxRenderer.this._button
						.getBounds();
				columnAlignedBox.x += dWidth;

				// check if in bounds of button
				if (columnAlignedBox.contains(evt.getPoint())) {

					if ((viewColumn == ProTreeTableHeaderSelectedIdxRenderer.this._column)
							&& (evt.getClickCount() == 1) && (column != -1)) {

						ProTreeTableHeaderSelectedIdxRenderer.this._button
								.setIcon(new ImageIcon(
										IconTreeTableView.ADD_IDX_VIEW_PRESSED));
						ProTreeTableHeaderSelectedIdxRenderer.this._mousePressed = true;
					}
				} else {
					ProTreeTableHeaderSelectedIdxRenderer.this._mousePressed = false;
				}
			}

			@Override
			public void mouseReleased(MouseEvent evt) {
				if (ProTreeTableHeaderSelectedIdxRenderer.this._mousePressed) {

					ProTreeTableHeaderSelectedIdxRenderer.this._button.setIcon(
							new ImageIcon(IconTreeTableView.ADD_IDX_VIEW));

					IndexViewDialog ivd = new IndexViewDialog();
					ivd.requestFocusInWindow();
					ivd.setVisible(true);

					int idxToAdd = -1;
					if (ivd.useInput()) {
						// OK button pressed
						try {
							idxToAdd = Integer.parseInt(ivd.getInput());
						} catch (NumberFormatException e1) {
						}
					}

					ivd.dispose();
					if (idxToAdd > 0) {
						// indices in magopt start at 0, in gui they start at 1
						ProTreeTableHeaderSelectedIdxRenderer.this._table
								.getIndexViewManager()
								.addIndexView(idxToAdd - 1);
					}

					ProTreeTableHeaderSelectedIdxRenderer.this._mousePressed = false;
				}
			}
		});
	}

	@Override
	public Component getTableCellRendererComponent(JTable table, Object value,
			boolean isSelected, boolean hasFocus, int row, int column) {

		if (table != null) {
			this._header = table.getTableHeader();
			if (this._header != null) {
				this.setForeground(this._header.getForeground());
				this.setBackground(this._header.getBackground());
				this.setFont(this._header.getFont());
			}
		}
		this._column = column;
		return this;
	}

	public void setSelectedIndex(int selectedIndex) {
		this._selectedIndex = selectedIndex;
		this._label.setText(" selected index: " + (this._selectedIndex + 1));
	}
}
