/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure;

import java.io.Serializable;
import java.rmi.Remote;
import java.rmi.RemoteException;

/**
 * Interface of depend-item
 * 
 * @author Werner Koppelsttter
 */
public interface IDependItem extends Remote, Serializable, Cloneable {

	/**
	 * Get Name of DependItem
	 * 
	 * @return Name
	 * @throws RemoteException
	 */
	public String getVarName() throws RemoteException;

	/**
	 * Get DependItem description
	 * 
	 * @return Description
	 * @throws RemoteException
	 */
	public PortDesc getVarDesc() throws RemoteException;

	/**
	 * Get parameter of DependItem
	 * 
	 * @return parameter
	 * @throws RemoteException
	 */
	public String getParam() throws RemoteException;

	/**
	 * Get handle of DependItem
	 * 
	 * @return Handle
	 * @throws RemoteException
	 */
	public IParameter getHandle() throws RemoteException;

	/**
	 * Get client-implementation of interface
	 * 
	 * @return Client-implementation
	 * @throws RemoteException
	 */
	public IDependItem getClientImpl() throws RemoteException;
}
