/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure;

import java.rmi.Remote;
import java.rmi.RemoteException;

/**
 * Interface for Parameter which dependent to other Parameters
 * 
 * @author Werner Koppelsttter
 */
public interface IDependency extends Remote {

	/**
	 * Refresh dependencies. Check whether the references are up-do-date and
	 * refresh them.
	 * 
	 * @param dirty
	 *            flag to indicate if parameter already changed
	 * @param load
	 *            flag to indicate loading parameter (no modification)
	 * @throws RemoteException
	 */
	public void refreshDepend(boolean dirty, boolean load)
			throws RemoteException;

	/**
	 * Get the depend object with the dependency structure
	 * 
	 * @return Depend object with dependency structure
	 * @throws RemoteException
	 */
	public IDepend getDepend() throws RemoteException;

	/**
	 * Refresh the dependencies of function
	 * 
	 * @throws RemoteException
	 */
	public void refreshDependency() throws RemoteException;

}
