/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure.client;

import java.rmi.RemoteException;

import at.lcm.bu21.magopt.structure.event.Event;
import at.lcm.bu21.magopt.structure.event.IEventLog;

/**
 * Client adapter for event-log interface
 * 
 * @author Werner Koppelsttter
 */
public class CEventLog implements IEventLog {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/** Event-log class */
	private IEventLog log;

	/**
	 * Create client adapter for event-log interface
	 * 
	 * @param log
	 *            Event log
	 */
	public CEventLog(IEventLog log) {
		this.log = log;
	}

	@Override
	public void add(Event evObj) throws RemoteException {
		this.log.add(evObj);
	}

	@Override
	public void clear() throws RemoteException {
		this.log.clear();
	}

	@Override
	public Event[] getBuffer(boolean info, boolean warning, boolean error)
			throws RemoteException {
		return this.log.getBuffer(info, warning, error);
	}

	@Override
	public int getMaxSize() throws RemoteException {
		return this.log.getMaxSize();
	}

	@Override
	public void setMaxSize(int size) throws RemoteException {
		this.log.setMaxSize(size);
	}

	@Override
	public void info(String identifier, String message,
			StackTraceElement[] stack) throws RemoteException {
		this.log.info(identifier, message, stack);
	}

	@Override
	public void warning(String identifier, String message,
			StackTraceElement[] stack) throws RemoteException {
		this.log.warning(identifier, message, stack);
	}

	@Override
	public void error(String identifier, String message,
			StackTraceElement[] stack) throws RemoteException {
		this.log.error(identifier, message, stack);
	}

	@Override
	public String toFullString() throws RemoteException {
		return this.log.toFullString();
	}

	@Override
	public String toStringI() throws RemoteException {
		return this.log.toStringI();
	}

	@Override
	public CEventLog getClientImpl() {
		return this;
	}
}
