/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.symspace;

import at.lcm.bu21.magopt.structure.jep.JepProxy;
import jep.Jep;
import jep.JepException;
import magopt.gui.console.PythonConsole;

/**
 * Start console version of SyMSpace
 *
 * @author Werner Koppelsttter
 */
public class Console {

	/**
	 * Start programs
	 * 
	 * @param args
	 *            Programm arugments
	 */
	public static void main(String[] args) {
		StringBuffer arguments;
		Jep jep;

		try {
			jep = JepProxy.configJep(null);

			for (String command : PythonConsole.initCommands()) {
				jep.eval(command);
			}

			if (args.length == 0) {
				// run interactive console
				jep.setInteractive(true);
				jep.eval("from jep import console");
				jep.set("jepInstance", jep);
				jep.eval("console.prompt(jepInstance)");
			} else {
				// run console with arguments
				arguments = new StringBuffer();
				for (String a : args) {
					arguments.append(",'");
					arguments.append(a);
					arguments.append("'");
				}
				arguments.deleteCharAt(0);

				jep.setInteractive(false);
				jep.eval("sys.argv = argv = " + arguments.toString().replace("\\", "\\\\").replace(":", "\\:"));
				jep.runScript(args[0]);
			}
		} catch (JepException e) {
			System.out.println(e.getMessage());
			e.printStackTrace();
			System.exit(1);
		}
	}

}
