/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.gui.view;

import java.awt.BorderLayout;
import java.awt.event.ComponentAdapter;
import java.awt.event.ComponentEvent;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.rmi.RemoteException;

import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.SwingConstants;
import javax.swing.SwingUtilities;

import at.lcm.bu21.magopt.structure.IParamMatlabFunction;
import at.lcm.bu21.magopt.structure.ParamMatlabFunction;

public class MatlabPreviewView extends ParamBaseNoScroll {

	private IParamMatlabFunction mPMatlabFunction;

	private JPanel mainPane;

	public MatlabPreviewView() {

		this.mainPane = new JPanel();
		this.setLayout(new BorderLayout());
		this.add(this.mainPane);

		this.mainPane.setLayout(new BorderLayout());
		this.mainPane.addComponentListener(new ComponentAdapter() {

			@Override
			public void componentResized(ComponentEvent e) {
				MatlabPreviewView.this.update();
			}
		});
		this.mainPane.addMouseListener(new MouseAdapter() {

			@Override
			public void mouseClicked(MouseEvent e) {
				if (e.getClickCount() > 1) {
					try {
						if (MatlabPreviewView.this.mPMatlabFunction.hasPreview()) {
							((ParamMatlabFunction) MatlabPreviewView.this.mPMatlabFunction).preview(null);
						}
					} catch (RemoteException e1) {
						e1.printStackTrace();
					}
				}
			}
		});
	}

	public void setMatlabFunction(IParamMatlabFunction pMatlabFunction) {
		this.mPMatlabFunction = pMatlabFunction;
		this.update();
	}

	@Override
	protected void update() {
		this.mainPane.removeAll();
		if (this.mPMatlabFunction != null) {
			SwingUtilities.invokeLater(new Runnable() {

				@Override
				public void run() {
					try {
						if (MatlabPreviewView.this.mPMatlabFunction.hasPreview()) {
							// FIXME RMI
							((ParamMatlabFunction) MatlabPreviewView.this.mPMatlabFunction)
									.preview(MatlabPreviewView.this.mainPane);
						} else {
							JLabel label = new JLabel("no preview");
							label.setHorizontalAlignment(SwingConstants.CENTER);
							label.setFont(label.getFont().deriveFont(24f));
							MatlabPreviewView.this.mainPane.add(label);
						}
					} catch (Exception e) {
						e.printStackTrace();
					}
				}
			});
		}
	}
}
