/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.gui.view.details;

import at.lcm.bu21.magopt.structure.IParamComboBox;
import at.lcm.bu21.magopt.structure.IParamContainer;
import at.lcm.bu21.magopt.structure.IParamDirectory;
import at.lcm.bu21.magopt.structure.IParamField;
import at.lcm.bu21.magopt.structure.IParamFile;
import at.lcm.bu21.magopt.structure.IParamFormula;
import at.lcm.bu21.magopt.structure.IParamJavaFunction;
import at.lcm.bu21.magopt.structure.IParamLinkedField;
import at.lcm.bu21.magopt.structure.IParamMaterial;
import at.lcm.bu21.magopt.structure.IParamMatlabFunction;
import at.lcm.bu21.magopt.structure.IParamPythonFunction;
import at.lcm.bu21.magopt.structure.IParamPythonFunction_old;
import at.lcm.bu21.magopt.structure.IParameter;
import at.lcm.bu21.magopt.structure.IProject;
import magopt.gui.view.ParamBaseNoScroll;
import magopt.gui.view.ParamBaseScroll;
import magopt.gui.view.ParamListener;

public class DetailView extends ParamBaseScroll implements ParamListener {

	private IParameter mParam;
	private ParamBaseNoScroll view;

	public void setParameter(IParameter param) {
		this.mParam = param;
		this.removeAll();
		if (this.mParam != null) {
			if (this.mParam instanceof IProject) {
				this.view = new ProjectView();
				this.view.addParamListener(this);
				this.add(this.view);
			} else if (this.mParam instanceof IParamMaterial) {
				this.view = new ParamMaterialView();
				this.view.addParamListener(this);
				this.add(this.view);
			} else if (this.mParam instanceof IParamJavaFunction) {
				this.view = new ParamJavaFunctionView();
				this.view.addParamListener(this);
				this.add(this.view);
			} else if (this.mParam instanceof IParamMatlabFunction) {
				this.view = new ParamMatlabFunctionView();
				this.view.addParamListener(this);
				this.add(this.view);
			} else if (this.mParam instanceof IParamPythonFunction) {
				this.view = new ParamPythonFunctionView();
				this.view.addParamListener(this);
				this.add(this.view);
			} else if (this.mParam instanceof IParamPythonFunction_old) {
				this.view = new ParamPythonFunctionOldView();
				this.view.addParamListener(this);
				this.add(this.view);
			} else if (this.mParam instanceof IParamContainer) {
				this.view = new ParamContainerView();
				this.view.addParamListener(this);
				this.add(this.view);
			} else if (this.mParam instanceof IParamComboBox) {
				this.view = new ParamComboBoxView();
				this.view.addParamListener(this);
				this.add(this.view);
			} else if (this.mParam instanceof IParamFormula) {
				this.view = new ParamFormulaView();
				this.view.addParamListener(this);
				this.add(this.view);
			} else if (this.mParam instanceof IParamLinkedField) {
				this.view = new ParamLinkedFieldView();
				this.view.addParamListener(this);
				this.add(this.view);
			} else if (this.mParam instanceof IParamField) {
				this.view = new ParamFieldView();
				this.view.addParamListener(this);
				this.add(this.view);
			} else if (this.mParam instanceof IParamFile) {
				this.view = new ParamFileView();
				this.view.addParamListener(this);
				this.add(this.view);
			} else if (this.mParam instanceof IParamDirectory) {
				this.view = new ParamDirectoryView();
				this.view.addParamListener(this);
				this.add(this.view);
			}
		}
		this.update();
	}

	@Override
	protected void update() {
		if (this.mParam != null) {
			if (this.mParam instanceof IProject) {
				((ProjectView) this.view).setProject((IProject) this.mParam);
			} else if (this.mParam instanceof IParamMaterial) {
				((ParamMaterialView) this.view).setMaterial((IParamMaterial) this.mParam);
			} else if (this.mParam instanceof IParamMatlabFunction) {
				((ParamMatlabFunctionView) this.view).setMatlabFunction((IParamMatlabFunction) this.mParam);
			} else if (this.mParam instanceof IParamPythonFunction) {
				((ParamPythonFunctionView) this.view).setPythonFunction((IParamPythonFunction) this.mParam);
			} else if (this.mParam instanceof IParamPythonFunction_old) {
				((ParamPythonFunctionOldView) this.view).setPythonFunction((IParamPythonFunction_old) this.mParam);
			} else if (this.mParam instanceof IParamJavaFunction) {
				((ParamJavaFunctionView) this.view).setJavaFunction((IParamJavaFunction) this.mParam);
			} else if (this.mParam instanceof IParamContainer) {
				((ParamContainerView) this.view).setContainer((IParamContainer) this.mParam);
			} else if (this.mParam instanceof IParamComboBox) {
				((ParamComboBoxView) this.view).setComboBox((IParamComboBox) this.mParam);
			} else if (this.mParam instanceof IParamFormula) {
				((ParamFormulaView) this.view).setFormula((IParamFormula) this.mParam);
			} else if (this.mParam instanceof IParamLinkedField) {
				((ParamLinkedFieldView) this.view).setLinkedField((IParamLinkedField) this.mParam);
			} else if (this.mParam instanceof IParamField) {
				((ParamFieldView) this.view).setField((IParamField) this.mParam);
			} else if (this.mParam instanceof IParamFile) {
				((ParamFileView) this.view).setFile((IParamFile) this.mParam);
			} else if (this.mParam instanceof IParamDirectory) {
				((ParamDirectoryView) this.view).setDirectory((IParamDirectory) this.mParam);
			}
		}
	}

	@Override
	public void parameterChanged() {
		this.fireParamChanged();
	}

}
