/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.gui.view.details;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.rmi.RemoteException;

import javax.swing.ButtonGroup;
import javax.swing.GroupLayout;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JTextField;

import at.lcm.bu21.magopt.structure.Access;
import at.lcm.bu21.magopt.structure.IParamPythonFunction_old;
import magopt.gui.view.ParamBaseNoScroll;
import magopt.gui.view.pubinterface.PubInterfaceView;

public class ParamPythonFunctionOldView extends ParamBaseNoScroll
		implements ActionListener, FocusListener {

	private JTextField mName;
	private JTextField mDescription;
	private JTextField mComment;

	protected JButton bEdit;
	protected JButton bShow;

	protected PubInterfaceView mPubInterface;

	protected ButtonGroup mAccessGroup;
	protected JRadioButton mAccessPublic;
	protected JRadioButton mAccessProtected;
	protected JRadioButton mAccessPrivate;

	protected JCheckBox mEnable;

	private IParamPythonFunction_old mPPythonFunction;

	public ParamPythonFunctionOldView() {
		JPanel mainPane = new JPanel();
		this.setLayout(new BorderLayout());
		this.add(mainPane);

		GroupLayout layout = new GroupLayout(mainPane);
		mainPane.setLayout(layout);
		layout.setAutoCreateGaps(true);
		layout.setAutoCreateContainerGaps(true);

		/* name */
		JLabel lName = new JLabel("Name:");
		this.mName = new JTextField();
		this.mName.addActionListener(this);
		this.mName.addFocusListener(this);

		/* description */
		JLabel lDesc = new JLabel("Description:");
		this.mDescription = new JTextField();
		this.mDescription.addActionListener(this);
		this.mDescription.addFocusListener(this);

		/* comment */
		JLabel lComment = new JLabel("Comment:");
		this.mComment = new JTextField();
		this.mComment.addActionListener(this);
		this.mComment.addFocusListener(this);

		/* edit */
		this.bEdit = new JButton("Edit (Python: )");
		this.bEdit.addActionListener(this);
		// this.bEdit.setEnabled(false);

		/* show */
		this.bShow = new JButton("Show");
		this.bShow.addActionListener(this);
		this.bShow.setEnabled(false);

		/* imports */
		JLabel lPubInterface = new JLabel("Interface:");
		this.mPubInterface = new PubInterfaceView();

		/* access */
		JLabel lAccess = new JLabel("Access:");
		this.mAccessGroup = new ButtonGroup();
		this.mAccessPublic = new JRadioButton("Public");
		this.mAccessPublic.addActionListener(this);
		// this.mAccessPublic.addFocusListener(this);
		this.mAccessGroup.add(this.mAccessPublic);
		this.mAccessProtected = new JRadioButton("Protected");
		this.mAccessProtected.addActionListener(this);
		// this.mAccessProtected.addFocusListener(this);
		this.mAccessGroup.add(this.mAccessProtected);
		this.mAccessPrivate = new JRadioButton("Private");
		this.mAccessPrivate.addActionListener(this);
		// this.mAccessPrivate.addFocusListener(this);
		this.mAccessGroup.add(this.mAccessPrivate);

		/* enable */
		JLabel lEnable = new JLabel("Enable:");
		this.mEnable = new JCheckBox();
		this.mEnable.addActionListener(this);
		this.mEnable.addFocusListener(this);

		/* config group layout */
		layout.setHorizontalGroup(layout.createSequentialGroup()
				.addGroup(layout
						.createParallelGroup(GroupLayout.Alignment.LEADING)
						.addComponent(lName).addComponent(lDesc)
						.addComponent(lComment).addComponent(lPubInterface)
						.addComponent(lAccess).addComponent(lEnable))
				.addGroup(layout
						.createParallelGroup(GroupLayout.Alignment.LEADING)
						.addComponent(this.mName)
						.addComponent(this.mDescription)
						.addComponent(this.mComment).addComponent(this.bEdit)
						.addComponent(this.bShow)
						.addComponent(this.mPubInterface)
						.addGroup(layout.createSequentialGroup()
								.addComponent(this.mAccessPublic)
								.addComponent(this.mAccessProtected)
								.addComponent(this.mAccessPrivate))
						.addComponent(this.mEnable)));
		layout.setVerticalGroup(layout.createSequentialGroup()
				.addGroup(layout
						.createParallelGroup(GroupLayout.Alignment.BASELINE)
						.addComponent(lName).addComponent(this.mName))
				.addGroup(layout
						.createParallelGroup(GroupLayout.Alignment.BASELINE)
						.addComponent(lDesc).addComponent(this.mDescription))
				.addGroup(layout
						.createParallelGroup(GroupLayout.Alignment.BASELINE)
						.addComponent(lComment).addComponent(this.mComment))
				.addGroup(layout
						.createParallelGroup(GroupLayout.Alignment.BASELINE)
						.addComponent(this.bEdit))
				.addGroup(layout
						.createParallelGroup(GroupLayout.Alignment.BASELINE)
						.addComponent(this.bShow))
				.addGroup(layout
						.createParallelGroup(GroupLayout.Alignment.BASELINE)
						.addComponent(lPubInterface)
						.addComponent(this.mPubInterface))
				.addGroup(layout
						.createParallelGroup(GroupLayout.Alignment.BASELINE)
						.addComponent(lAccess).addComponent(this.mAccessPublic)
						.addComponent(this.mAccessProtected)
						.addComponent(this.mAccessPrivate))
				.addGroup(layout
						.createParallelGroup(GroupLayout.Alignment.BASELINE)
						.addComponent(lEnable).addComponent(this.mEnable)));

	}

	@Override
	public void focusGained(FocusEvent e) {
		/* do nothing */
	}

	@Override
	public void focusLost(FocusEvent e) {
		this.doWork(e.getSource());
	}

	@Override
	public void actionPerformed(ActionEvent e) {
		this.doWork(e.getSource());
	}

	private void doWork(Object obj) {
		try {
			if (obj == this.mName) {
				this.mPPythonFunction.setName(this.mName.getText());
			} else if (obj == this.mDescription) {
				this.mPPythonFunction
						.setDescription(this.mDescription.getText());
			} else if (obj == this.mComment) {
				this.mPPythonFunction.setComment(this.mComment.getText());
			} else if (obj == this.bEdit) {
				this.mPPythonFunction.edit();
			} else if (obj == this.bShow) {
				this.mPPythonFunction.show();
			} else if (obj == this.mAccessPublic) {
				if (this.mAccessPublic.isSelected()) {
					this.mPPythonFunction.setAccess(Access.PUBLIC);
				}
			} else if (obj == this.mAccessProtected) {
				if (this.mAccessProtected.isSelected()) {
					this.mPPythonFunction.setAccess(Access.PROTECTED);
				}
			} else if (obj == this.mAccessPrivate) {
				if (this.mAccessPrivate.isSelected()) {
					this.mPPythonFunction.setAccess(Access.PRIVATE);
				}
			} else if (obj == this.mEnable) {
				this.mPPythonFunction.setEnable(this.mEnable.isSelected());
			}
		} catch (RemoteException ex) {
			ex.printStackTrace();
		} catch (Exception ex) {
			try {
				this.mPPythonFunction.error(ex.getMessage(),
						ex.getStackTrace());
			} catch (RemoteException e) {
				e.printStackTrace();
			}
		}

		this.update();
		this.fireParamChanged();
	}

	public void setPythonFunction(IParamPythonFunction_old pPythonFunction) {
		this.mPPythonFunction = pPythonFunction;
		this.update();
	}

	@Override
	protected void update() {
		try {
			this.mName.setText(this.mPPythonFunction.getName());
			this.mDescription.setText(this.mPPythonFunction.getDescription());
			this.mComment.setText(this.mPPythonFunction.getComment());
			this.bEdit.setText("Edit (Python: "
					+ this.mPPythonFunction.getClassName() + ")");
			this.bShow.setEnabled(this.mPPythonFunction.hasShow());
			switch (this.mPPythonFunction.getAccess()) {
			case PUBLIC:
				this.mAccessPublic.setSelected(true);
				break;
			case PROTECTED:
				this.mAccessProtected.setSelected(true);
				break;
			case PRIVATE:
				this.mAccessPrivate.setSelected(true);
				break;
			}
			this.mPubInterface.setContainer(this.mPPythonFunction);
			this.mEnable.setSelected(this.mPPythonFunction.isEnable());
		} catch (RemoteException e) {
			e.printStackTrace();
		}
	}

}
