/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.gui.view.summary;

import java.awt.Color;
import java.awt.Component;
import java.awt.Font;
import java.rmi.RemoteException;

import javax.swing.JTable;
import javax.swing.SwingConstants;
import javax.swing.table.DefaultTableCellRenderer;

import magopt.gui.icons.IconParameter;
import at.lcm.bu21.magopt.structure.IParameter;

/**
 * Summary renderer for parameter type.<br>
 * Displays an icon for every parameter type.
 * 
 * @author Aigner Markus
 * @author Werner Koppelsttter
 */
public class SummaryRenderer extends DefaultTableCellRenderer {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	@Override
	public Component getTableCellRendererComponent(JTable table, Object value,
			boolean isSelected, boolean hasFocus, int row, int column) {
		Font font;

		super.getTableCellRendererComponent(table, value, isSelected, hasFocus,
				row, column);

		if (column == SummaryColumn.TYPE.getValue()) {
			this.setIcon(IconParameter.getIcon((IParameter) value));
			this.setText(null);
			this.setToolTipText(value.getClass().getSimpleName());
			this.setHorizontalAlignment(SwingConstants.CENTER);
		} else {
			this.setIcon(null);
			this.setText((String) value);
			this.setToolTipText(this.getText());
			this.setHorizontalAlignment(SwingConstants.LEFT);
		}

		try {
			if (((IParameter) table.getModel().getValueAt(row, -1)).getUsed()) {
				this.setForeground(Color.BLACK);
			} else {
				this.setForeground(Color.LIGHT_GRAY);
			}
		} catch (RemoteException e) {
			this.setForeground(Color.BLACK);
			e.printStackTrace();
		}

		font = this.getFont();
		if ((column == SummaryColumn.VALUE.getValue())
				&& !table.getModel().isCellEditable(row, column)) {
			if (!font.isItalic()) {
				font = font.deriveFont(Font.ITALIC);
			}
		} else {
			if (!font.isItalic()) {
				font = font.deriveFont(Font.PLAIN);
			}
		}
		this.setFont(font);

		try {
			if ((column == SummaryColumn.VALUE.getValue())
					&& ((IParameter) table.getModel().getValueAt(row, -1))
							.getModified()) {
				this.setBackground(Color.YELLOW);
			} else {
				this.setBackground(Color.WHITE);

			}
		} catch (RemoteException e) {
			this.setBackground(Color.WHITE);
			e.printStackTrace();
		}

		return this;
	}
}
