/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.structure.database;

import java.util.LinkedList;

/**
 * Represent a diagram-object from database
 * 
 * @author Werner Koppelsttter
 */
public class MaterialDiagram {

	/** Name of diagram */
	protected String name;
	/** Description of diagram */
	protected String description;
	/** List with diagram-axis */
	protected LinkedList<MaterialProperty<Double[]>> axis = new LinkedList<MaterialProperty<Double[]>>();

	/**
	 * Construct a diagram object
	 * 
	 * @param name
	 *            Name
	 * @param description
	 *            Description
	 * @param axis
	 *            List of axis
	 */
	public MaterialDiagram(String name, String description,
			LinkedList<MaterialProperty<Double[]>> axis) {
		this.name = name;
		this.description = description;
		this.axis = axis;
	}

	/**
	 * Get name of diagram
	 * 
	 * @return Name
	 */
	public String getName() {
		return this.name;
	}

	/**
	 * Get description of diagram
	 * 
	 * @return Description
	 */
	public String getDescription() {
		return this.description;
	}

	/**
	 * Get list of axis
	 * 
	 * @return List of axis
	 */
	public LinkedList<MaterialProperty<Double[]>> getAxis() {
		return axis;
	}
}
