/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 247 $
 * $Date: 2020-03-19 10:13:52 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.optim.core.mapping.utils.dstructures;

/**
 * Constants used throughout the Optimizer application
 * 
 * @author Ciprian Zavoianu
 */
public class TMappingConstants {

	public enum TExperimentType {
		CV_EVALUATION_REG("CV_EVALUATION_REG"), CV_EVALUATION_CLS("CV_EVALUATION_CLS"),
		MODEL_TRAINING_REG("MODEL_TRAINING_REG"), MODEL_TRAINING_CLS("MODEL_TRAINING_CLS");

		public static boolean contains(String value) {
			for (TExperimentType e : TExperimentType.values()) {
				if (e.getValue().toUpperCase().equals(value.toUpperCase())) {
					return true;
				}
			}
			return false;
		}

		private final String value;

		TExperimentType(String value) {
			this.value = value;
		}

		public String getValue() {
			return this.value;
		}
	};

	public enum THolderState {
		IDLE("PAUSED_WITHOUT_MODEL"), READY("PAUSED_WITH_MODEL"), BUSY("CREATING_MODEL");

		private final String value;

		THolderState(String value) {
			this.value = value;
		}

		public String getValue() {
			return this.value;
		}
	};

	public enum TRegressionModelType {
		ANN("ANN"), SMO_POLY("SMO_POLY"), SMO_RBF("SMO_RBF"), LINEAR("LINEAR"), ISOTONIC("ISOTONIC"),
		RBF_NET("RBF_NET"), LOGISTIC("LOGISTIC");

		public static boolean contains(String value) {
			for (TRegressionModelType r : TRegressionModelType.values()) {
				if (r.getValue().toUpperCase().equals(value.toUpperCase())) {
					return true;
				}
			}
			return false;
		}

		private final String value;

		TRegressionModelType(String value) {
			this.value = value;
		}

		public String getValue() {
			return this.value;
		}
	};

	public enum TThreadState {
		IDLE("NOT_STARTED"), READY("HAS_RESULTS"), RUNNING("RUNNING");

		private final String value;

		TThreadState(String value) {
			this.value = value;
		}

		public String getValue() {
			return this.value;
		}
	};

	// public final static int NR_OF_FOLDS = 10;
	public final static String TRAINING_PREFIX = "_training_";
	public final static String TEST_PREFIX = "_test_";
	public final static String EXPERIMENT_MASTER_FILE = "ExperimentMasterFile.txt";
	public final static String BASE_DATASET_FILE = "BaseDataset.arff";
	public final static String REMOTE_TASK_BATCH_FILE_NAME = "Result_taskBatch.tbf";
	public final static String REMOTE_MODEL_FILE_NAME = "remoteModel.model";
	public final static String ERRORS_CLASSIFIER = "Errors-Classifier";
	public final static int MAX_NR_OF_TRAINING_ATTEMPTS = 3;
	public final static String NO_ERROR = "10.0";
	public final static String ERROR = "-10.0";
	public final static double ENSEMBLE_QUALITY_THRESHOLD = 0.9;
	public final static int DEFAULT_NR_OF_TRAINING_SAMPLES = 2000;
	public final static int DEFAULT_MAPPING_CREATION_TIME_LIMIT = 60;
	public final static int MIN_NR_OF_TRAINING_SAMPLES = 50;
	public final static int MIN_MAPPING_CREATION_TIME_LIMIT = 3;
	public final static int MAX_MAPPING_CREATION_TIME_LIMIT = 180;
	public final static double DEFAULT_SENSITIVITY_RANGE = 0.01;
	public final static double MAX_SENSITIVITY_RANGE = 0.10;
	public final static int DEFAULT_SENSITIVITY_INTERVALS = 5;
	public final static int MAX_SENSITIVITY_EVALUATIONS = 1000;
	public final static int MAX_VARIABLES_FOR_SENSITIVITY_GRID_SEARCH = 9;
	public final static int MAX_STORED_SENSITIVITY_ANALYSES = 5;

	public final static String KEY_VALUE_SPLIT = "[\\s]*=[\\s]*";
	public final static String PARAM_ARRAY_SPLIT = "[\\s]*,[\\s]*";
	public final static String KEY_ARRAY_SPLIT = "[\\s]*,[\\s]*|[\\s]*=[\\s]*";
}
