/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 247 $
 * $Date: 2020-03-19 10:13:52 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.optim.core.mapping.utils.dstructures;

import java.io.Serializable;

public class TSensitivityCell implements Serializable {
	private static final long serialVersionUID = -0200000000000000313L;

	Double varMin;
	Double varMax;
	Double varAbsRange;
	Double varPercentualRange;
	Double resMin;
	Double resMax;
	Double resAbsRange;
	Double resPercentualRange;
	Double resRelativeRange;
	Double resNormRelativeRange;
	Double resMinAbsoluteRange;
	Double resMaxAbsoluteRange;

	public TSensitivityCell() {
		super();
		this.varMin = Double.MAX_VALUE;
		this.varMax = -Double.MAX_VALUE;
		this.varAbsRange = 0.0;
		this.varPercentualRange = 0.0;
		this.resMin = Double.MAX_VALUE;
		this.resMax = -Double.MAX_VALUE;
		this.resAbsRange = 0.0;
		this.resPercentualRange = 0.0;
		this.resRelativeRange = 0.0;
		this.resNormRelativeRange = -1.0;
		this.resMaxAbsoluteRange = -Double.MAX_VALUE;
		this.resMinAbsoluteRange = -Double.MAX_VALUE;
	}

	public void updateCell(double newVariableValue, double newResultValue, double baseIndividualVarValue,
			double baseIndividualResValue) {
		if (newResultValue > this.resMax) {
			this.resMax = newResultValue;
		}

		if (newResultValue < this.resMin) {
			this.resMin = newResultValue;
		}

		if (newVariableValue > this.varMax) {
			this.varMax = newVariableValue;
		}

		if (newVariableValue < this.varMin) {
			this.varMin = newVariableValue;
		}

		this.varAbsRange = this.varMax - this.varMin;
		this.resAbsRange = this.resMax - this.resMin;

		this.varPercentualRange = this.varAbsRange / Math.abs(baseIndividualVarValue);

		this.resPercentualRange = this.resAbsRange / Math.abs(baseIndividualResValue);

		if (this.varPercentualRange != 0) {

			this.resRelativeRange = this.resPercentualRange / this.varPercentualRange;
		} else {
			this.resRelativeRange = 0.0;
		}

		if ((newResultValue - baseIndividualResValue) > this.resMaxAbsoluteRange) {
			this.resMaxAbsoluteRange = newResultValue - baseIndividualResValue;
		}

		if ((baseIndividualResValue - newResultValue) > this.resMinAbsoluteRange) {
			this.resMinAbsoluteRange = baseIndividualResValue - newResultValue;
		}

		// System.out
		// .println("Updated TCell with: NewVar=" + newVariableValue
		// + " NewRes=" + newResultValue + " BaseVar="
		// + baseIndividualVarValue + " BaseRes="
		// + baseIndividualResValue);
	}

	public Double getVarMin() {
		return this.varMin;
	}

	public void setVarMin(Double varMin) {
		this.varMin = varMin;
	}

	public Double getVarMax() {
		return this.varMax;
	}

	public void setVarMax(Double varMax) {
		this.varMax = varMax;
	}

	public Double getVarAbsRange() {
		return this.varAbsRange;
	}

	public void setVarAbsRange(Double varAbsRange) {
		this.varAbsRange = varAbsRange;
	}

	public Double getVarPercentualRange() {
		return this.varPercentualRange;
	}

	public void setVarPercentualRange(Double varPercentualRange) {
		this.varPercentualRange = varPercentualRange;
	}

	public Double getResMin() {
		return this.resMin;
	}

	public void setResMin(Double resMin) {
		this.resMin = resMin;
	}

	public Double getResMax() {
		return this.resMax;
	}

	public void setResMax(Double resMax) {
		this.resMax = resMax;
	}

	public Double getResAbsRange() {
		return this.resAbsRange;
	}

	public void setResAbsRange(Double resAbsRange) {
		this.resAbsRange = resAbsRange;
	}

	public Double getResPercentualRange() {
		return this.resPercentualRange;
	}

	public void setResPercentualRange(Double resPercentualRange) {
		this.resPercentualRange = resPercentualRange;
	}

	public Double getResRelativeRange() {
		return this.resRelativeRange;
	}

	public void setResRelativeRange(Double resRelativeRange) {
		this.resRelativeRange = resRelativeRange;
	}

	public Double getResNormRelativeRange() {
		return this.resNormRelativeRange;
	}

	public void setResNormRelativeRange(Double resNormRelativeRange) {
		this.resNormRelativeRange = resNormRelativeRange;
	}

	public Double getResMinAbsoluteRange() {
		return this.resMinAbsoluteRange;
	}

	public void setResMinAbsoluteRange(Double resMinAbsoluteRange) {
		this.resMinAbsoluteRange = resMinAbsoluteRange;
	}

	public Double getResMaxAbsoluteRange() {
		return this.resMaxAbsoluteRange;
	}

	public void setResMaxAbsoluteRange(Double resMaxAbsoluteRange) {
		this.resMaxAbsoluteRange = resMaxAbsoluteRange;
	}

	public Double getRelativeResToDisplay() {
		// return this.varPercentualRange;
		return this.resRelativeRange;
		// return this.resNormRelativeRange;
	}

	public Double getAbsoluteMinResToDisplay() {
		return this.resMinAbsoluteRange;
	}

	public Double getAbsoluteMaxResToDisplay() {
		return this.resMaxAbsoluteRange;
	}

	public void updateAbsoluteMinResToDisplay(double newResultValue, double baseIndividualResValue) {
		if ((newResultValue - baseIndividualResValue) > this.resMaxAbsoluteRange) {
			this.resMaxAbsoluteRange = newResultValue - baseIndividualResValue;
		}
	}

	public void updateAbsoluteMaxResToDisplay(double newResultValue, double baseIndividualResValue) {
		if ((baseIndividualResValue - newResultValue) > this.resMinAbsoluteRange) {
			this.resMinAbsoluteRange = baseIndividualResValue - newResultValue;
		}
	}
}
