#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 9518 $
$LastChangedDate:: 2019-12-19 17:02:33 +0100#$

This file is part of SyMSpace.

Copyright (c) 2019, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""
from symspace.console.script_utils import ScriptUtils
from symspace.wrapper.symwrapper import SymProject, SymContainer
from symspace.generic_gui_qt import GUIFormThread


def main(project: SymProject, parameter):
    if isinstance(parameter, SymContainer):
        raise Exception('Containers are not supported for export!')
    else:
        form_title = 'Select how to plot'
        form_elements = [
                         ('Axis-1', 'line', parameter.getIdentifier()),
                         ('Axis-2', 'line', 'indices'),
                         ('Plot Mode:', 'label'),
                         ('Histogram', 'checkbox', True),
                         ('Line', 'checkbox', False),
                         ('Bar', 'checkbox', False),
                         ]
        form = GUIFormThread(form_title, form_elements)

        form.start()

        if form.accept:
            id1 = form.result['Axis-1']
            id2 = form.result['Axis-2']

            axis1 = project[id1]
            args = [axis1, ]
            if id2 != 'indices':
                args.append(project[id2])

            if form.result['Histogram']:
                project.plotParamHistogramm(axis1).show()
            if form.result['Line']:
                project.plotParameter(*args, mode='line').show()
            if form.result['Bar']:
                project.plotParameter(*args, mode='bar').show()
        else:
            print('Cancelled by user')


if __name__ == '__main__':
    """
    This script plots the current variable over indices

    This script needs to be executed in the SyMSpace Python Console.
    """

    ScriptUtils.runWithParams(main, locals())
