# !/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 9896 $
$LastChangedDate:: 2020-06-30 08:41:38 +0200#$

This file is part of SyMSpace.

Copyright (c) 2020, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""
import os
import time
import unittest
from symspace.osutils.processutils import getInterpreter
from symspace.osutils.pathutils import symspace_home
from symspace.wrapper.symwrapper import SymProject, SymSimulateAll


class TestJobinterface(unittest.TestCase):

    @staticmethod
    def run_sim(sym_file: str) -> tuple:
        sym_prj = SymProject.load(sym_file)
        sym_prj.getEventLog()

        sim_all = SymSimulateAll(sym_prj)
        sim_all.setRunSimulation(True)
        sim_all.setRemoteCompute(False)
        sim_all.setOptimize(False)
        sim_all.start()

        while sim_all.getNumNotInitialized() > 0:
            print('initializing...')
            time.sleep(2)
        while sim_all.getNumIncomplete() > 0 and sim_all.getRunSimulation():
            print('running...')
            time.sleep(2)

        status = sim_all.getNumError() + sim_all.getNumIncomplete()

        event_log = sym_prj.getEventLog()
        if 'Error' in event_log:
            status += 1

        sym_prj.close()
        return status, event_log

    @unittest.skipIf(getInterpreter() == 'python', 'needs jep interpreter to run')
    def test_run_job(self):
        sym_file = os.path.join(symspace_home, 'System', 'Python', 'tests', 'test_symspace', 'test_jobinterface',
                                'projects', 'RunPythonJob', 'RunPythonJob.mop')

        status, event_log = self.run_sim(sym_file)

        if status == 0:
            print('Global Update completed successfully, as expected')
        else:
            print('Warning: Global Update incomplete')
            print(event_log)
            self.fail('Global Update incomplete')

    @unittest.skipIf(getInterpreter() == 'python', 'needs jep interpreter to run')
    def test_run_job_failing(self):
        sym_file = os.path.join(symspace_home, 'System', 'Python', 'tests', 'test_symspace', 'test_jobinterface',
                                'projects', 'RunPythonJobFail', 'RunPythonJobFail.mop')

        status, event_log = self.run_sim(sym_file)

        if status == 0:
            print('Warning: Global Update completed successfully')
            print(event_log)
            self.fail('The project was meant to fail, but did not!')
        else:
            print('Global Update incomplete, as expected')

    @unittest.skipIf(getInterpreter() == 'python', 'needs jep interpreter to run')
    def test_run_job_exitcode(self):
        sym_file = os.path.join(symspace_home, 'System', 'Python', 'tests', 'test_symspace', 'test_jobinterface',
                                'projects', 'RunPythonJobExitCode', 'RunPythonJobExitCode.mop')

        status, event_log = self.run_sim(sym_file)

        if status == 0:
            print('Warning: Global Update completed successfully')
            print(event_log)
            self.fail('The project was meant to fail, but did not!')
        else:
            print('Global Update incomplete, as expected')


if __name__ == '__main__':
    from lcm.utils.testing import runUnittest

    runUnittest(getInterpreter())
