/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9720 $
 * $Date: 2020-03-19 15:59:49 +0100 (Thu, 19 Mar 2020) $
 */
package jobmanager.server;

import java.io.IOException;
import java.net.ServerSocket;
import java.net.Socket;

/**
 * Listen to the given port an start JobListener with new connection
 * 
 * @author Werner Koppelsttter
 */
class SocketListener extends Thread {

	/** ServerSocket of listener */
	protected ServerSocket ss;

	/**
	 * Create a SocketListener to listen for a new connection
	 * 
	 * @param port
	 *            Port to listen for new connections
	 * @throws IOException
	 */
	public SocketListener(int port) throws IOException {
		this.ss = new ServerSocket(port);
		this.start();
	}

	/**
	 * Listen to the given port for new connections
	 */
	@Override
	public void run() {
		Socket s;
		while (true) {
			try {
				s = this.ss.accept();
				if (s.getLocalAddress().getHostAddress()
						.compareTo(s.getInetAddress().getHostAddress()) == 0) {
					while (JobListener.count > 10) {
						Thread.sleep(10);
					}
					new JobListener(s);
				} else {
					s.close();
				}
			} catch (Exception e) {
			}
		}

	}

	/**
	 * Get used port
	 * 
	 * @return Used port
	 */
	public int getPort() {
		return this.ss.getLocalPort();
	}
}
