/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9720 $
 * $Date: 2020-03-19 15:59:49 +0100 (Thu, 19 Mar 2020) $
 */
package jobmanager.server.gui;

/**
 * Connects column indices with column header names.
 * 
 * @author Werner Koppelsttter
 */
public enum JobListColumn {
	/** Project of job */
	PROJECT(0, "Project"),
	/** Dataset of job */
	DATASET(1, "DS"),
	/** Parameter of job */
	PARAMETER(2, "Param"),
	/** Name of job */
	NAME(3, "Name"),
	/** Status of job */
	STATUS(4, "Status"),
	/** ID of execution */
	ID(5, "ID"),
	/** Runtime of execution */
	RUNTIME(6, "Runtime"),
	/** Host of execution */
	HOST(7, "Host");

	/** Column number */
	private final int mColumn;
	/** Column name */
	private final String mName;

	/**
	 * Create enumeration
	 * 
	 * @param column
	 *            Column number
	 * @param name
	 *            Column name
	 */
	private JobListColumn(int column, String name) {
		this.mColumn = column;
		this.mName = name;
	}

	/**
	 * Get column number
	 * 
	 * @return Number
	 */
	protected int getValue() {
		return (this.mColumn);
	}

	/**
	 * Get column name
	 * 
	 * @return Name
	 */
	protected String getName() {
		return (this.mName);
	}

}
